pub struct AprsItem {
pub name: Vec<u8>,
pub live: bool,
pub position: Position,
pub extension: Option<Extension>,
pub comment: Vec<u8>,
}Expand description
An APRS Item Report.
DTI: )
Items are similar to objects but lack a timestamp and have a variable-length name (3–9 characters). They are intended for inanimate things reported occasionally on a map (checkpoints, aid posts, etc.).
Fields
name: Vec<u8>Item name (3–9 chars; any char except ! and ).
live: booltrue if the item is live/active (!); false if killed ( ).
position: Positionextension: Option<Extension>Optional data extension (course/speed, PHG, RNG, DFS).
comment: Vec<u8>Implementations