pub struct MicEDevice {
pub manufacturer: String,
pub model: String,
}Expand description
Manufacturer and model of the radio that generated this MIC-E packet, decoded from the manufacturer prefix/suffix bytes in the info field.
Fields
manufacturer: Stringmodel: StringTrait Implementations
Sourceimpl Clone for MicEDevice
impl Clone for MicEDevice
Sourcefn clone(&self) -> MicEDevice
fn clone(&self) -> MicEDevice
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MicEDevice
impl Debug for MicEDevice
Sourceimpl PartialEq for MicEDevice
impl PartialEq for MicEDevice
Sourcefn eq(&self, other: &MicEDevice) -> bool
fn eq(&self, other: &MicEDevice) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for MicEDevice
impl StructuralPartialEq for MicEDevice