Symbol

Struct Symbol 

pub struct Symbol {
    pub table: char,
    pub code: char,
}
An APRS position symbol, consisting of a symbol table identifier and a symbol code.

  • table == '/': primary symbol table
  • table == '\\': alternate symbol table
  • table is 'A'..='Z' or '0'..='9': alternate table with an alphanumeric overlay

Fields

table: charcode: char

Implementations

Source

impl Symbol

pub fn new(table: char, code: char) -> Self

pub fn is_primary_table(self) -> bool

pub fn is_alternate_table(self) -> bool

pub fn overlay(self) -> Option<char>

Returns the overlay character if this symbol uses an alphanumeric overlay.

pub fn description(self) -> Option<&'static str>

Look up the human-readable description of this symbol.

Returns None for reserved, overlay-only, or TNC-internal codes.