pub enum Extension {
DirectionSpeed {
direction_degrees: u16,
speed_knots: u16,
},
Phg {
power_watts: u32,
antenna_height_feet: u32,
antenna_gain_db: u8,
directivity: Directivity,
},
Rng {
range_miles: u16,
},
Dfs {
s_points: u8,
antenna_height_feet: u32,
antenna_gain_db: u8,
directivity: Directivity,
},
}Expand description
A data extension field that follows the position in the comment field.
Extensions occupy exactly 7 bytes and are encoded in a fixed format that depends on the extension type. Unknown or malformed extensions are discarded (the caller treats the entire comment field as the comment in that case).
Variants
DirectionSpeed
Course (degrees) and speed (knots). Format: DDD/SSS.
Phg
Power-Height-Gain-Directivity. Format: PHGphgd.
Rng
Pre-calculated radio range. Format: RNGrrrr.
Dfs
DF Strength-Height-Gain-Directivity. Format: DFSshgd.
Implementations