pub struct Symbol {
pub table: char,
pub code: char,
}Expand description
An APRS position symbol, consisting of a symbol table identifier and a symbol code.
table == '/': primary symbol tabletable == '\\': alternate symbol tabletableis'A'..='Z'or'0'..='9': alternate table with an alphanumeric overlay
Fields
table: charcode: charImplementations
Sourceimpl Symbol
impl Symbol
pub fn new(table: char, code: char) -> Self
pub fn is_primary_table(self) -> bool
pub fn is_alternate_table(self) -> bool
Sourcepub fn overlay(self) -> Option<char>
pub fn overlay(self) -> Option<char>
Returns the overlay character if this symbol uses an alphanumeric overlay.
Sourcepub fn description(self) -> Option<&'static str>
pub fn description(self) -> Option<&'static str>
Look up the human-readable description of this symbol.
Returns None for reserved, overlay-only, or TNC-internal codes.